@@ -20,7 +20,7 @@ pub struct Compression;
 impl<E: Endpoint> Middleware<E> for Compression {
     type Output = CompressionEndpoint<E>;
 
-    fn transform(self, ep: E) -> Self::Output {
+    fn transform(&self, ep: E) -> Self::Output {
         CompressionEndpoint { ep }
     }
 }
